@@ -27,11 +27,13 @@ class SimpleTermTests(unittest.TestCase):
 
     def test_class_conforms_to_ITokenizedTerm(self):
         from zope.interface.verify import verifyClass
+
         from zope.schema.interfaces import ITokenizedTerm
         verifyClass(ITokenizedTerm, self._getTargetClass())
 
     def test_instance_conforms_to_ITokenizedTerm(self):
         from zope.interface.verify import verifyObject
+
         from zope.schema.interfaces import ITokenizedTerm
         verifyObject(ITokenizedTerm, self._makeOne('VALUE'))
 
@@ -58,6 +60,13 @@ class SimpleTermTests(unittest.TestCase):
         self.assertEqual(term.token, 'term')
         self.assertFalse(ITitledTokenizedTerm.providedBy(term))
 
+    def test_bytes_non_ascii_value(self):
+        from zope.schema.interfaces import ITitledTokenizedTerm
+        term = self._makeOne(b'Snowman \xe2\x98\x83')
+        self.assertEqual(term.value, b'Snowman \xe2\x98\x83')
+        self.assertEqual(term.token, 'Snowman \\xe2\\x98\\x83')
+        self.assertFalse(ITitledTokenizedTerm.providedBy(term))
+
     def test_unicode_non_ascii_value(self):
         from zope.schema.interfaces import ITitledTokenizedTerm
         term = self._makeOne(u'Snowman \u2603')
@@ -65,10 +74,7 @@ class SimpleTermTests(unittest.TestCase):
         self.assertEqual(term.token, 'Snowman \\u2603')
         self.assertFalse(ITitledTokenizedTerm.providedBy(term))
 
-
     def test__eq__and__hash__(self):
-        from zope import interface
-
         term = self._makeOne('value')
         # Equal to itself
         self.assertEqual(term, term)
@@ -112,16 +118,19 @@ class SimpleVocabularyTests(unittest.TestCase):
 
     def test_class_conforms_to_IVocabularyTokenized(self):
         from zope.interface.verify import verifyClass
+
         from zope.schema.interfaces import IVocabularyTokenized
         verifyClass(IVocabularyTokenized, self._getTargetClass())
 
     def test_instance_conforms_to_IVocabularyTokenized(self):
         from zope.interface.verify import verifyObject
+
         from zope.schema.interfaces import IVocabularyTokenized
         verifyObject(IVocabularyTokenized, self._makeOne(()))
 
     def test_ctor_additional_interfaces(self):
         from zope.interface import Interface
+
         from zope.schema.vocabulary import SimpleTerm
 
         class IStupid(Interface):
@@ -142,6 +151,7 @@ class SimpleVocabularyTests(unittest.TestCase):
 
     def test_fromValues(self):
         from zope.interface import Interface
+
         from zope.schema.interfaces import ITokenizedTerm
 
         class IStupid(Interface):
@@ -158,6 +168,7 @@ class SimpleVocabularyTests(unittest.TestCase):
 
     def test_fromItems(self):
         from zope.interface import Interface
+
         from zope.schema.interfaces import ITokenizedTerm
 
         class IStupid(Interface):
@@ -175,6 +186,7 @@ class SimpleVocabularyTests(unittest.TestCase):
 
     def test_fromItems_triples(self):
         from zope.interface import Interface
+
         from zope.schema.interfaces import ITitledTokenizedTerm
 
         class IStupid(Interface):
@@ -359,8 +371,9 @@ class TreeVocabularyTests(unittest.TestCase):
             self.assertTrue(ITitledTokenizedTerm.providedBy(term))
 
     def test_implementation(self):
-        from zope.interface.verify import verifyObject
         from zope.interface.common.mapping import IEnumerableMapping
+        from zope.interface.verify import verifyObject
+
         from zope.schema.interfaces import ITreeVocabulary
         from zope.schema.interfaces import IVocabulary
         from zope.schema.interfaces import IVocabularyTokenized
@@ -380,10 +393,10 @@ class TreeVocabularyTests(unittest.TestCase):
         self.assertTrue(IStupid.providedBy(v))
 
     def test_ordering(self):
-        #The TreeVocabulary makes use of an OrderedDict to store it's
-        #internal tree representation.
+        # The TreeVocabulary makes use of an OrderedDict to store its
+        # internal tree representation.
         #
-        #Check that they keys are indeed oredered.
+        # Check that the keys are indeed ordered.
         from collections import OrderedDict
 
         d = {
@@ -641,7 +654,7 @@ class TreeVocabularyTests(unittest.TestCase):
             self.assertEqual(str(e), "Term tokens must be unique: 'one'")
 
     def test_recursive_methods(self):
-        #Test the _createTermTree and _getPathToTreeNode methods
+        # Test the _createTermTree and _getPathToTreeNode methods
         from zope.schema.vocabulary import _createTermTree
         tree = _createTermTree({}, self.business_tree())
         vocab = self._getTargetClass().fromDict(self.business_tree())
@@ -674,7 +687,7 @@ class TreeVocabularyTests(unittest.TestCase):
 
 
 class RegistryTests(unittest.TestCase):
-    #Tests of the simple vocabulary and presentation registries.
+    # Tests of the simple vocabulary and presentation registries.
 
     def setUp(self):
         from zope.schema.vocabulary import _clear
@@ -685,8 +698,8 @@ class RegistryTests(unittest.TestCase):
         _clear()
 
     def test_setVocabularyRegistry(self):
-        from zope.schema.vocabulary import setVocabularyRegistry
         from zope.schema.vocabulary import getVocabularyRegistry
+        from zope.schema.vocabulary import setVocabularyRegistry
         r = _makeDummyRegistry()
         setVocabularyRegistry(r)
         self.assertTrue(getVocabularyRegistry() is r)
@@ -702,6 +715,7 @@ class RegistryTests(unittest.TestCase):
 
 def _makeSampleVocabulary():
     from zope.interface import implementer
+
     from zope.schema.interfaces import IVocabulary
 
     class SampleTerm(object):
@@ -716,7 +730,7 @@ def _makeSampleVocabulary():
         def __contains__(self, value):
             return 0 <= value < 10
 
-        def __len__(self): # pragma: no cover
+        def __len__(self):  # pragma: no cover
             return 10
 
         def getTerm(self, value):
